@@ -3,8 +3,8 @@ from docx import Document
 
 def readox(temp_path : str):
 
-    print("读取模板文件...",end="")
+    logging.info("读取模板文件...")
     doc = Document(temp_path)
-    print("成功")
+    logging.info("成功")
 
     return doc
